netapp_ontap.models.aws_kms_state API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aws_kms_state`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AwsKmsStateSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AwsKmsState object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cluster_state: bool GET`

    Set to true when AWS KMS key protection is available on all nodes of the cluster.

  `code: str GET`

    Code corresponding to the message. Returns a 0 if AWS KMS key protection is available on all nodes of the cluster.

    Example: 346758

  `message: str GET`

    Error message set when cluster_state is false.

    Example: AWS KMS key protection is unavailable on the following nodes: node1, node2.